@@ -165,7 +165,7 @@ class Changelog(object):
         """
         Возвращает True если в секции unreleased есть changes
         """
-        if self.unreleased.change_blocks:
+        if self.unreleased:
             if len(self.unreleased.change_blocks):
                 for item in self.unreleased.change_blocks:
                     if len(self.unreleased.change_blocks[item].changes) > 0:
